# lightDict
lightsmile的一些工具词典。

以后一些nlp相关的字典词典等都会放到这里。这些数据既可以直接下载使用，也可以使用lightDict辅助库来在Python中使用。

## 声明

由于词典和汉字加起来超过70M，所以这里提供[百度网盘链接](https://pan.baidu.com/s/1ZpDZKiLyD7HVIvCoOirRCg)，提取码是`e78m`。

## 数据来源

### 字典

1. [pwxcoo/chinese-xinhua: 中华新华字典数据库。包括歇后语，成语，词语，汉字。](https://github.com/pwxcoo/chinese-xinhua)

### 词典

1. [pwxcoo/chinese-xinhua: 中华新华字典数据库。包括歇后语，成语，词语，汉字。](https://github.com/pwxcoo/chinese-xinhua)
2. [近义词查询_反义词查询_同义词查询 - KM查询](https://kmcha.com/similar)

## 数据格式：

### 字典

```bash
character,pinyin,explanation
嗄,á,"嗄〈叹〉 同啊”。表示省悟或惊奇 嗄!难道这里是没有地方官的么?--宋·佚名《新编五代史平话》 嗄á叹词。在句首，〈表〉疑问或反问～，这是什么？～，你想干什么？""嗄""另见shà㈠。 嗄shà ⒈声音嘶哑～声。 嗄a 1.助词。表示强调﹑肯定或辩解。 2.助词。方言。表示疑问或反诘。 嗄xià 1.见""嗄饭""。 2.见""嗄程""。"
吖,ā,喊叫天～地。  形容喊叫的声音高声叫～～。 吖ā［吖啶黄］（-dìnghuáng）〈名〉一种注射剂。  ────────────────—    吖yā 1.呼;喊。
阿,ā,"阿〈助〉    (汉语名词词头,盛行于魏晋以后)    加在亲属称呼前面有亲昵的意味    阿姊闻妹来。--《乐府诗集·木兰诗》    府吏得闻之,堂上启阿母。--《玉台新咏·古诗为焦仲卿妻作》。　    又如阿爷(又作阿耶”。称父亲);阿翁(称祖父;称父亲;妇女称丈夫之父);阿嫂(对朋友之妻的称呼);阿叔(对丈夫之弟的称呼);阿家(又称阿姑”。妇人称丈夫的母亲);阿爹(称父亲;也尊称长者);阿父(称父亲;也称伯伯、叔叔,或作伯叔自称);阿伯(尊称年长的男子)    加于某些人的姓、名、小名、排行前用作称呼,往往带有一定的感情色彩或尊卑关系    阿女含泪答。--《玉台新咏·古诗为焦仲卿妻作》。    又如阿咸(侄子。晋朝阮籍的侄儿阮咸有才,后来遂用来称侄子);阿连(弟弟。南朝宋谢灵运的族弟惠连很有才,人们随谢灵运称之为阿连);阿杜(原指周盘龙的小妾杜氏,后为妾的别称);阿娇(汉武帝陈皇后的小名;泛指美丽的女子);阿蒙(三国时吴国名将吕蒙);阿瞒(三国曹操的小字)    阿ā    ⒈助词。用在称呼前～姨。～哥。～张。    ⒉［阿昌族］我国少数民族之 一。    阿 ē    ①凹曲处山～。    ②迎合；偏袒～谀。又见ā。    【阿弥陀佛】梵文的音译。佛经中西方极乐世界的教主。佛教寺庙中常与释迦、药师佛并供。佛教徒以之作为口头念诵的佛号，表示虔诚信仰。又意译作'无量寿佛'、'无量光佛'。    【阿房宫】秦代著名宫殿。遗址在西安市西阿房村。始建于前212年，规模极为宏大，'东西五里，南北千步'，全部工程至秦亡时犹未完成，故未正式命名，时人用其前殿所在地名而称之为阿房宫。秦亡后，被项羽焚毁。    【阿其所好】无原则地迎合别人的爱好。    【阿谀】为迎合别人，说好听的话。    阿ǎ 1.叹词。表示惊讶。    阿à 1.方言。副词。犹言可﹑是否。用在问句中，加强语气。    阿a 1.语气词。用在句首或句中。无义。 2.语气词。用在句末表示肯定﹑嘱咐﹑乞请等语气。 3.语气词◇作""啊""。用在句中稍作停顿，让人注意下面的话。"
啊,ā,"啊  (形声。从口,阿声。本义叹词) 表示惊叹或赞颂。如啊!多么美丽的夜色;啊!祖国,我为您歌唱 啊á叹词。在句首，〈表〉疑问或反问～，这是什么？～，你想干什么？ 啊ǎ叹词。在句首，〈表〉疑惑～，这东西质量可靠吗？ 啊ɑ助词。 ①在句尾，〈表〉惊奇、赞叹等语气，常因前面字音的不同，而有各种变音。也可用别的字来表示快来～（呀）！你们好～（哇）！大家加油干～（哪）！ ②用于列举事项之后米～、菜～、肉～，丰富极了。 啊à叹词。〈表〉应允、领悟或惊叹～，好吧，照你说的办！～，知道了！～，大鱼上钩了！ 啊ā叹词。在句首，〈表〉赞叹或惊奇～，太好了！～，太阳出来了！ 啊a 1.助词。用在句末表示感叹的语气。 2.助词。用在句末表示肯定﹑辩解﹑催促﹑嘱咐等语气。 3.助词。用在句末表示疑问的语气。 4.助词。用在句中表示停顿。 5.助词。用在列举的事项之后。"
锕,ā,"锕  一种放射性的三价金属元素,原子序数89,其化学性质类似于镧,由镤经放射α粒子生成,半衰期为22年,尤见于沥青铀矿中--元素符号ac 锕ā化学元素。符号ac。具有放射性。"
```

### 词典

```bash
word,pinyin,mean,syns,ants,sims
嵞山,tú shān,1.即涂山。山名，即浙江省的会稽山。相传夏禹大会诸侯于此。 2.即涂山。嵞山国，古国名，在今安徽省怀远县东南。,,,"余尝考,耦之,四书释地,夫赋,盖本于,非匹,舅者,余之生,文在兹,常季曰,乃古圣,以咎,详诸,张大之,鬼谷子·捭阖,宁谓,兹且,夫神者,淮南子?精神训,宋王禹,此舜,之莫能,抑又何,身之文,氏注,苟有志,释吾,兹名,赖其功,本此意"
虚位,xū wèi,1.空的坐位。 2.空着的职位;有名无实的职位。 3.特意空出职位。表示期待贤能。 4.空名号。,,,"旷量,转向手感,指向精准,电子助力,转向力度,转向精准,回正力,路感清晰,阻尼,路感,指向准确,转向灵敏,电动助力转向,刹车力度,顿挫感,液压助力,转向比,方向盘助力,回正力矩,电动助力,闯动,机械液压助力,变速箱换挡,油门灵敏,反馈力度,液压助力转向,悬挂偏硬,悬架调校,转向助力,高速过弯"
税期,shuì qī,1.征税的时期。,,,"缴准,企业缴税,央行逆回购,短期流动性,月度缴税,财政存款,到期资金,mlf到期,市场资金面,央行公开市场操作,重启逆回购,存准,法定存款准备金,回收流动性,半年末,mpa考核,净投放,逆回购,公开市场操作,跨月,净回笼,银行体系流动性,回笼货币,资金面,国库现金定存,资金利率,央票,资金面紧张,央行释放流动性,紧势"
盛乐,shèng yuè,1.盛大的乐曲。,,,"平城,盛乐城,什翼,拔魏,漠南,拓跋鲜卑,燕都,五原,和林格尔县,慕容俊,拓跋,晋阳,北燕,邺城,赫连勃勃,邺,代北,临潢府,鲜卑,代国,弹汗山,赫连昌,夏国,武川,鲜卑人,鲜卑拓跋,汉国,拓跋圭,河套,中京"
敛束,liǎn shù,1.犹收缩。 2.约束，收敛。,,,"之气益,条鬯,宜涩,益伤,然其病,灵枢·小针解,偏陂,然阴,已漓,挛拳,此皆得,阴燥,倒辄,殆谓,虚因,寓气,冥乎,故其功,恣用,呈逸,味辛则,浮而升,充悦,细而沉,深而留,然其势,褚法,太素.刺法,取其涩,正惟"
单于,chán yú,1.汉时匈奴君长的称号。 2.曲调名。,,,"冒顿,大单于,匈奴王,匈奴单于,匈奴,阏氏,右贤王,可汗,左贤王,匈奴人,日逐王,冒顿单于,突厥可汗,单于庭,头曼,军臣单于,鲜卑,呼韩邪,突厥,伊稚斜,东胡,月氏,轲比能,呼厨泉,左谷蠡王,郅支单于,启民可汗,鲜卑人,颉利,檀石槐"
咫见,zhǐ jiàn,1.短浅的见识。,,,
玉蚁,yù yǐ,"1.见""玉蚁""。",,,
```

## 安装

```bash
pip install lightDict
```
建议使用国内源来安装，如使用以下命令：

```bash
pip install -i https://pypi.douban.com/simple/ lightDict
```

## 功能


### 1.字典

使用示例：
```python
from lightdict import HanziDict

hanzi_dic = HanziDict(r'D:\Data\NLP\corpus\words\hanzi.csv')


print('和' in hanzi_dic)
x = hanzi_dic['哈']
print(x)
```

输出结果：

```bash
True
{
 "pattern": "哈",
 "pinyin": "hā",
 "mean": "哈〈动〉 (形声。从口,合声。本义以唇啜饮。同歃”) 张口呼气  哈  身子略弯,以此表示礼貌(不及鞠躬郑重)  哈　 口  臾儿、易牙,淄 渑之水合者,尝一哈水而甘苦知矣;故圣人之论贤也,见其一行而贤不肖分矣。--《淮南子·汜论训》 哈〈叹〉 --表示满意、惊喜或赞叹  哈〈象〉 笑声  黄檗哈哈大笑。--道原《景德传灯录》 哈 哈hā ⒈张口呼气～气。 ⒉ ⒊ ①含油食物，存放时久，起了变化的味道。 ②杀死（多见于元曲）。 ⒋ ⒌ ①我国少数民族之一。 ②哈萨克斯坦的主要民族。 哈hǎ ⒈姓。 ⒉ ⒊ 哈hà 哈hē 1.饮;喝。"
}
```

### 2.词典

使用示例：

```python
from lightdict import WordDict

word_dict = WordDict(r'D:\Data\NLP\corpus\words\words.csv')

print('开云见日' in word_dict)
print(word_dict['开云见日'])
```

输出结果：

```bash
True
{
 "word": "开云见日",
 "pinyin": [
  "kāi yún jiàn rì"
 ],
 "syns": [
  "重见天日",
  "开云见天"
 ],
 "ants": [
  "暗无天日",
  "乌云蔽日"
 ],
 "sims": [
  "月缺重圆",
  "玉汝成",
  "欣欣自得",
  "驰风骋雨",
  "暗换年华",
  "日短心长",
  "函盖乾坤",
  "拔犀擢象",
  "诗·郑风·风雨",
  "昧旦晨兴",
  "雨霾风障",
  "月章星句",
  "一谦四益",
  "山奔海立",
  "箕风毕雨",
  "焕作",
  "鲲鹏图南",
  "鸿踏雪泥",
  "日月不居",
  "舟水之喻",
  "沧桑陵谷",
  "乐成人美",
  "鲁阳挥戈",
  "古辞云",
  "哀乐相生",
  "收缘结果",
  "欣欣物自私",
  "海桑陵谷",
  "有感人生",
  "泰极而否"
 ]
}
```


### 高级功能
其中`HanziDict`和`WordDict`对象也可以作为上下文管理器来使用，在初始化时指定`keep`参数为`False`,则系统只会在上下文管理器作用域下将字典数据调入程序以节省内存，待程序运行跳出该上下文后将自动调用内存回收功能以释放词典占用内存，省去了需要用户显式调用如`release`方法来实现相应功能。

```python
from lightdict import WordDict, HanziDict

hanzi_dic = HanziDict(r'D:\Data\NLP\corpus\words\hanzi.csv', keep=False)

word_dict = WordDict(r'D:\Data\NLP\corpus\words\words.csv', keep=False)

with hanzi_dic:
    print('和' in hanzi_dic)

with word_dict:
    print('开云见日' in word_dict)
```

执行结果：

```bash
True
True
```

## 参考

1. [pwxcoo/chinese-xinhua: 中华新华字典数据库。包括歇后语，成语，词语，汉字。](https://github.com/pwxcoo/chinese-xinhua)
2. [近义词查询_反义词查询_同义词查询 - KM查询](https://kmcha.com/similar)
3. [Override Python's 'in' operator? - Stack Overflow](https://stackoverflow.com/questions/2217001/override-pythons-in-operator)
4. [【整理】Python中将（字典，列表等）变量格式化成（漂亮的，树形的，带缩进的，JSON方式的）字符串输出 – 在路上](https://www.crifan.com/format_dictionary_list_variable_into_prettified_tree_like_with_indent_json_string_then_output/)
5. [abc --- 抽象基类 — Python 3.8.1 文档](https://docs.python.org/zh-cn/3/library/abc.html)
6. [Python csv空行 写入csv文件 中间隔一行空行 的解决 - 兔子昂](https://www.tuziang.com/combat/714.html)

